@@ -1096,7 +1096,8 @@ def populate_efitviewer_figure(
         printe('Gridspec keywords for setting up efitviewer profile plots were invalid and were ignored!')
 
     if show_cx:
-        cx_ax = scratch['efitviewer_cx_ax'] = fig.add_subplot(gs[:, 0])
+        pyplot.figure(num=fig.number)
+        cx_ax = scratch['efitviewer_cx_ax'] = pyplot.subplot(gs[:, 0])
     else:
         cx_ax = scratch['efitviewer_cx_ax'] = None
 
@@ -1127,7 +1128,8 @@ def populate_efitviewer_figure(
                 sharey = profile_axs[0, col]
         else:
             sharey = None
-        profile_axs[row, col] = fig.add_subplot(gs[row, fig_col], sharex=sharex, sharey=sharey)
+        pyplot.figure(num=fig.number)
+        profile_axs[row, col] = pyplot.subplot(gs[row, fig_col], sharex=sharex, sharey=sharey)
         if (row < (num_rows - 1)) and (profiles_sharex in ['col', 'all']):
             profile_axs[row, col].get_xaxis().set_visible(False)
         if (col > 0) and profiles_sharey in ['row', 'all']:
