@@ -851,8 +851,9 @@ If this file is not available to you contact the GA computer group: iris-support
         username, password = get_rdb_password(server0)
         if username != rdb_server[0]:
             printw(
-                "username from get_rdb_password({}) ({}) != username indicated by MainSettings ({})".format(
-                    server0, username, rdb_server[0]
+                "`get_rdb_password('{}')` username is `{}` is different from username `{}` indicated in MainSettings\n"
+                "Use `set_rdb_password('{}', username='{}', password=...)` to setup username/password associated with this server.".format(
+                    server0, username, rdb_server[0], server0, rdb_server[0]
                 )
             )
         self.username = username
